@@ -641,7 +641,7 @@ function test_containers_denseaxisarray_vector_any()
     key_1 = Any[Any["a", 1], "b"]
     key_2 = Any[Any["a", 2], "c"]
     K = Any[key_1, key_2]
-    Containers.@container(x[k = K], k[1][2])
+    Containers.@container(x[k=K], k[1][2])
     @test axes(x) == (K,)
     @test x[key_1] == 1
     @test x[key_2] == 2
@@ -652,7 +652,7 @@ end
 
 function test_containers_denseaxisarray_ambiguous_slice()
     K = Any[Any["a"], Any["b"], Any[Any["a"], Any["b"]]]
-    Containers.@container(x[k = K], length(k))
+    Containers.@container(x[k=K], length(k))
     @test axes(x) == (K,)
     @test x[Any["a"]] == 1
     @test x[Any["b"]] == 1
@@ -671,10 +671,10 @@ function test_containers_denseaxisarray_ambiguous_slice()
 end
 
 function test_containers_denseaxisarray_kwarg_indexing()
-    Containers.@container(x[i = 2:3, j = 1:2], i + j,)
+    Containers.@container(x[i=2:3, j=1:2], i + j)
     for i in (2, 3, 2:2, 2:3, :), j in (1, 2, 1:2, 1:1, 2:2, :)
-        @test x[i = i, j = j] == x[i, j]
-        @test_throws ErrorException x[j = j, i = i]
+        @test x[i=i, j=j] == x[i, j]
+        @test_throws ErrorException x[j=j, i=i]
     end
     @test_throws(
         ErrorException(
@@ -682,7 +682,7 @@ function test_containers_denseaxisarray_kwarg_indexing()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[j = 1, i = 2],
+        x[j=1, i=2],
     )
     @test_throws(
         ErrorException(
@@ -690,30 +690,30 @@ function test_containers_denseaxisarray_kwarg_indexing()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[i = 2, k = 2],
+        x[i=2, k=2],
     )
     @test_throws(
         ErrorException(
             "Cannot index with mix of positional and keyword arguments",
         ),
-        x[i = 2, 2],
+        x[i=2, 2],
     )
-    Containers.@container(y[i = 2:3, 1:2], i)
+    Containers.@container(y[i=2:3, 1:2], i)
     @test_throws(
         ErrorException(
             "Cannot index with mix of positional and keyword arguments",
         ),
-        y[i = 2, 2],
+        y[i=2, 2],
     )
     return
 end
 
 function test_containers_denseaxisarray_kwarg_setindex()
-    Containers.@container(x[i = 2:3, j = 1:2], i + j,)
+    Containers.@container(x[i=2:3, j=1:2], i + j)
     for i in 2:3, j in 1:2
-        @test x[i = i, j = j] == i + j
-        x[i = i, j = j] = i + j + 2
-        @test x[i = i, j = j] == i + j + 2
+        @test x[i=i, j=j] == i + j
+        x[i=i, j=j] = i + j + 2
+        @test x[i=i, j=j] == i + j + 2
     end
     @test_throws(
         ErrorException(
@@ -721,7 +721,7 @@ function test_containers_denseaxisarray_kwarg_setindex()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[j = 1, i = 2] = 2,
+        x[j=1, i=2] = 2,
     )
     @test_throws(
         ErrorException(
@@ -729,34 +729,34 @@ function test_containers_denseaxisarray_kwarg_setindex()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[i = 2, k = 2] = 2,
+        x[i=2, k=2] = 2,
     )
     @test_throws(
         ErrorException(
             "Cannot index with mix of positional and keyword arguments",
         ),
-        x[i = 2, 2] = 3,
+        x[i=2, 2] = 3,
     )
     return
 end
 
 function test_containers_denseaxisarray_kwarg_indexing_slicing()
-    Containers.@container(x[i = 2:3, j = 1:2], i + j,)
-    y = x[i = 2, j = :]
-    @test y[j = 2] == 4
-    y = x[i = :, j = 1]
-    @test y[i = 3] == 4
+    Containers.@container(x[i=2:3, j=1:2], i + j)
+    y = x[i=2, j = :]
+    @test y[j=2] == 4
+    y = x[i = :, j=1]
+    @test y[i=3] == 4
     y = x[i = :, j = :]
-    @test y[i = 3, j = 1] == 4
+    @test y[i=3, j=1] == 4
     return
 end
 
 function test_containers_denseaxisarrayview_kwarg_indexing()
-    Containers.@container(a[i = 2:3, j = 1:2], i + j,)
+    Containers.@container(a[i=2:3, j=1:2], i + j)
     x = view(a, :, :)
     for i in (2, 3, 2:2, 2:3, :), j in (1, 2, 1:2, 1:1, 2:2, :)
-        @test x[i = i, j = j] == x[i, j]
-        @test_throws ErrorException x[j = j, i = i]
+        @test x[i=i, j=j] == x[i, j]
+        @test_throws ErrorException x[j=j, i=i]
     end
     @test_throws(
         ErrorException(
@@ -764,7 +764,7 @@ function test_containers_denseaxisarrayview_kwarg_indexing()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[j = 1, i = 2],
+        x[j=1, i=2],
     )
     @test_throws(
         ErrorException(
@@ -772,22 +772,22 @@ function test_containers_denseaxisarrayview_kwarg_indexing()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[i = 2, k = 2],
+        x[i=2, k=2],
     )
     @test_throws(
         ErrorException(
             "Cannot index with mix of positional and keyword arguments",
         ),
-        x[i = 2, 2],
+        x[i=2, 2],
     )
     return
 end
 
 function test_containers_denseaxisarrayview_kwarg_indexing_drop_dim()
-    Containers.@container(a[i = 2:3, j = 1:2], i + j,)
+    Containers.@container(a[i=2:3, j=1:2], i + j)
     x = view(a, 2, 1:2)
     for j in (1, 2, 1:2, 1:1, 2:2, :)
-        @test x[j = j] == x[j]
+        @test x[j=j] == x[j]
     end
     @test_throws(
         ErrorException(
@@ -795,30 +795,30 @@ function test_containers_denseaxisarrayview_kwarg_indexing_drop_dim()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[i = 2],
+        x[i=2],
     )
     return
 end
 
 function test_containers_denseaxisarrayview_kwarg_indexing_slicing()
-    Containers.@container(a[i = 2:3, j = 1:2], i + j,)
+    Containers.@container(a[i=2:3, j=1:2], i + j)
     x = view(a, :, :)
-    y = x[i = 2, j = :]
-    @test y[j = 2] == 4
-    y = x[i = :, j = 1]
-    @test y[i = 3] == 4
+    y = x[i=2, j = :]
+    @test y[j=2] == 4
+    y = x[i = :, j=1]
+    @test y[i=3] == 4
     y = x[i = :, j = :]
-    @test y[i = 3, j = 1] == 4
+    @test y[i=3, j=1] == 4
     return
 end
 
 function test_containers_denseaxisarrayview_kwarg_setindex()
-    Containers.@container(a[i = 2:3, j = 1:2], i + j,)
+    Containers.@container(a[i=2:3, j=1:2], i + j)
     x = view(a, :, :)
     for i in 2:3, j in 1:2
-        @test x[i = i, j = j] == i + j
-        x[i = i, j = j] = i + j + 2
-        @test x[i = i, j = j] == i + j + 2
+        @test x[i=i, j=j] == i + j
+        x[i=i, j=j] = i + j + 2
+        @test x[i=i, j=j] == i + j + 2
     end
     @test_throws(
         ErrorException(
@@ -826,7 +826,7 @@ function test_containers_denseaxisarrayview_kwarg_setindex()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[j = 1, i = 2] = 2,
+        x[j=1, i=2] = 2,
     )
     @test_throws(
         ErrorException(
@@ -834,23 +834,19 @@ function test_containers_denseaxisarrayview_kwarg_setindex()
             "indices must match the exact name and order used when creating " *
             "the container.",
         ),
-        x[i = 2, k = 2] = 2,
+        x[i=2, k=2] = 2,
     )
     @test_throws(
         ErrorException(
             "Cannot index with mix of positional and keyword arguments",
         ),
-        x[i = 2, 2] = 3,
+        x[i=2, 2] = 3,
     )
     return
 end
 
 function test_sum_dims()
-    Containers.@container(
-        x[i = 1:2, j = 1:2],
-        i + j,
-        container = DenseAxisArray,
-    )
+    Containers.@container(x[i=1:2, j=1:2], i + j, container = DenseAxisArray)
     @test_throws(
         ErrorException(
             "`sum(x::DenseAxisArray; dims)` is not supported. Convert the array " *
@@ -863,9 +859,9 @@ function test_sum_dims()
 end
 
 function test_multi_arg_eachindex()
-    Containers.@container(x[i = 2:3], i)
-    Containers.@container(y[i = 2:3], i)
-    Containers.@container(z[i = 2:4, j = 1:2], i + j)
+    Containers.@container(x[i=2:3], i)
+    Containers.@container(y[i=2:3], i)
+    Containers.@container(z[i=2:4, j=1:2], i + j)
     @test eachindex(x) == CartesianIndices((2,))
     @test eachindex(y) == CartesianIndices((2,))
     @test eachindex(z) == CartesianIndices((3, 2))
@@ -934,7 +930,7 @@ function test_promote_shape()
 end
 
 function test_container_Base_OneTo_Integer()
-    Containers.@container(x[i = 0x01:0x08], 2 * i)
+    Containers.@container(x[i=0x01:0x08], 2 * i)
     @test x[0x01:0x02] == Containers.@container([i = 0x01:0x02], 2 * i)
     return
 end
