@@ -141,7 +141,7 @@ function test_printing_expressions()
     # This is really just to check IJulia printing for expressions
     mod = Model()
     @variable(mod, x[1:5])
-    @variable(mod, y[i = 2:4, j = i:5])
+    @variable(mod, y[i=2:4, j=i:5])
     @variable(mod, z)
 
     ex = @expression(mod, x[1] + 2 * y[2, 3])
@@ -887,7 +887,7 @@ function test_print_hermitian_psd_cone()
     @test sprint(io -> show(io, MIME("text/plain"), c)) ==
           "[x[1]  im\n -im   x[2]] $in_sym $(HermitianPSDCone())"
     @test sprint(io -> show(io, MIME("text/latex"), c)) ==
-          "\$\$ \\begin{bmatrix}\nx_{1} & im\\\\\n-im & x_{2}\\\\\n\\end{bmatrix} \\in \\text{$(HermitianPSDCone())} \$\$"
+          "\$\$ \\begin{bmatrix}\nx_{1} & i\\\\\n-i & x_{2}\\\\\n\\end{bmatrix} \\in \\text{$(HermitianPSDCone())} \$\$"
     return
 end
 
@@ -911,6 +911,8 @@ function test_print_complex_string_round()
         -1.0-1.0im=>"(-1 - im)",
     ]
         @test JuMP._string_round(MIME("text/plain"), test) == result
+        latex_result = replace(result, "im" => "i")
+        @test JuMP._string_round(MIME("text/latex"), test) == latex_result
     end
     return
 end
